alpha

package
v0.0.7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 16, 2026 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the alpha type in the database.
	Label = "alpha"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldUUID holds the string denoting the uuid field in the database.
	FieldUUID = "Uuid"
	// FieldFirstInsert holds the string denoting the firstinsert field in the database.
	FieldFirstInsert = "FirstInsert"
	// FieldLastUpdate holds the string denoting the lastupdate field in the database.
	FieldLastUpdate = "LastUpdate"
	// FieldAnimal holds the string denoting the animal field in the database.
	FieldAnimal = "Animal"
	// FieldBigNumber holds the string denoting the bignumber field in the database.
	FieldBigNumber = "BigNumber"
	// FieldTestField holds the string denoting the testfield field in the database.
	FieldTestField = "test_field"
	// Table holds the table name of the alpha in the database.
	Table = "alpha"
)

Variables

var (
	// UUIDValidator is a validator for the "Uuid" field. It is called by the builders before save.
	UUIDValidator func(string) error
	// AnimalValidator is a validator for the "Animal" field. It is called by the builders before save.
	AnimalValidator func(string) error
)

Columns holds all SQL columns for alpha fields.

Functions

func And

func And(predicates ...predicate.Alpha) predicate.Alpha

And groups predicates with the AND operator between them.

func Animal

func Animal(v string) predicate.Alpha

Animal applies equality check predicate on the "Animal" field. It's identical to AnimalEQ.

func AnimalContains

func AnimalContains(v string) predicate.Alpha

AnimalContains applies the Contains predicate on the "Animal" field.

func AnimalContainsFold

func AnimalContainsFold(v string) predicate.Alpha

AnimalContainsFold applies the ContainsFold predicate on the "Animal" field.

func AnimalEQ

func AnimalEQ(v string) predicate.Alpha

AnimalEQ applies the EQ predicate on the "Animal" field.

func AnimalEqualFold

func AnimalEqualFold(v string) predicate.Alpha

AnimalEqualFold applies the EqualFold predicate on the "Animal" field.

func AnimalGT

func AnimalGT(v string) predicate.Alpha

AnimalGT applies the GT predicate on the "Animal" field.

func AnimalGTE

func AnimalGTE(v string) predicate.Alpha

AnimalGTE applies the GTE predicate on the "Animal" field.

func AnimalHasPrefix

func AnimalHasPrefix(v string) predicate.Alpha

AnimalHasPrefix applies the HasPrefix predicate on the "Animal" field.

func AnimalHasSuffix

func AnimalHasSuffix(v string) predicate.Alpha

AnimalHasSuffix applies the HasSuffix predicate on the "Animal" field.

func AnimalIn

func AnimalIn(vs ...string) predicate.Alpha

AnimalIn applies the In predicate on the "Animal" field.

func AnimalLT

func AnimalLT(v string) predicate.Alpha

AnimalLT applies the LT predicate on the "Animal" field.

func AnimalLTE

func AnimalLTE(v string) predicate.Alpha

AnimalLTE applies the LTE predicate on the "Animal" field.

func AnimalNEQ

func AnimalNEQ(v string) predicate.Alpha

AnimalNEQ applies the NEQ predicate on the "Animal" field.

func AnimalNotIn

func AnimalNotIn(vs ...string) predicate.Alpha

AnimalNotIn applies the NotIn predicate on the "Animal" field.

func BigNumber

func BigNumber(v string) predicate.Alpha

BigNumber applies equality check predicate on the "BigNumber" field. It's identical to BigNumberEQ.

func BigNumberContains

func BigNumberContains(v string) predicate.Alpha

BigNumberContains applies the Contains predicate on the "BigNumber" field.

func BigNumberContainsFold

func BigNumberContainsFold(v string) predicate.Alpha

BigNumberContainsFold applies the ContainsFold predicate on the "BigNumber" field.

func BigNumberEQ

func BigNumberEQ(v string) predicate.Alpha

BigNumberEQ applies the EQ predicate on the "BigNumber" field.

func BigNumberEqualFold

func BigNumberEqualFold(v string) predicate.Alpha

BigNumberEqualFold applies the EqualFold predicate on the "BigNumber" field.

func BigNumberGT

func BigNumberGT(v string) predicate.Alpha

BigNumberGT applies the GT predicate on the "BigNumber" field.

func BigNumberGTE

func BigNumberGTE(v string) predicate.Alpha

BigNumberGTE applies the GTE predicate on the "BigNumber" field.

func BigNumberHasPrefix

func BigNumberHasPrefix(v string) predicate.Alpha

BigNumberHasPrefix applies the HasPrefix predicate on the "BigNumber" field.

func BigNumberHasSuffix

func BigNumberHasSuffix(v string) predicate.Alpha

BigNumberHasSuffix applies the HasSuffix predicate on the "BigNumber" field.

func BigNumberIn

func BigNumberIn(vs ...string) predicate.Alpha

BigNumberIn applies the In predicate on the "BigNumber" field.

func BigNumberLT

func BigNumberLT(v string) predicate.Alpha

BigNumberLT applies the LT predicate on the "BigNumber" field.

func BigNumberLTE

func BigNumberLTE(v string) predicate.Alpha

BigNumberLTE applies the LTE predicate on the "BigNumber" field.

func BigNumberNEQ

func BigNumberNEQ(v string) predicate.Alpha

BigNumberNEQ applies the NEQ predicate on the "BigNumber" field.

func BigNumberNotIn

func BigNumberNotIn(vs ...string) predicate.Alpha

BigNumberNotIn applies the NotIn predicate on the "BigNumber" field.

func FirstInsert

func FirstInsert(v string) predicate.Alpha

FirstInsert applies equality check predicate on the "FirstInsert" field. It's identical to FirstInsertEQ.

func FirstInsertContains

func FirstInsertContains(v string) predicate.Alpha

FirstInsertContains applies the Contains predicate on the "FirstInsert" field.

func FirstInsertContainsFold

func FirstInsertContainsFold(v string) predicate.Alpha

FirstInsertContainsFold applies the ContainsFold predicate on the "FirstInsert" field.

func FirstInsertEQ

func FirstInsertEQ(v string) predicate.Alpha

FirstInsertEQ applies the EQ predicate on the "FirstInsert" field.

func FirstInsertEqualFold

func FirstInsertEqualFold(v string) predicate.Alpha

FirstInsertEqualFold applies the EqualFold predicate on the "FirstInsert" field.

func FirstInsertGT

func FirstInsertGT(v string) predicate.Alpha

FirstInsertGT applies the GT predicate on the "FirstInsert" field.

func FirstInsertGTE

func FirstInsertGTE(v string) predicate.Alpha

FirstInsertGTE applies the GTE predicate on the "FirstInsert" field.

func FirstInsertHasPrefix

func FirstInsertHasPrefix(v string) predicate.Alpha

FirstInsertHasPrefix applies the HasPrefix predicate on the "FirstInsert" field.

func FirstInsertHasSuffix

func FirstInsertHasSuffix(v string) predicate.Alpha

FirstInsertHasSuffix applies the HasSuffix predicate on the "FirstInsert" field.

func FirstInsertIn

func FirstInsertIn(vs ...string) predicate.Alpha

FirstInsertIn applies the In predicate on the "FirstInsert" field.

func FirstInsertLT

func FirstInsertLT(v string) predicate.Alpha

FirstInsertLT applies the LT predicate on the "FirstInsert" field.

func FirstInsertLTE

func FirstInsertLTE(v string) predicate.Alpha

FirstInsertLTE applies the LTE predicate on the "FirstInsert" field.

func FirstInsertNEQ

func FirstInsertNEQ(v string) predicate.Alpha

FirstInsertNEQ applies the NEQ predicate on the "FirstInsert" field.

func FirstInsertNotIn

func FirstInsertNotIn(vs ...string) predicate.Alpha

FirstInsertNotIn applies the NotIn predicate on the "FirstInsert" field.

func ID

func ID(id int) predicate.Alpha

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id int) predicate.Alpha

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id int) predicate.Alpha

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id int) predicate.Alpha

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...int) predicate.Alpha

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id int) predicate.Alpha

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id int) predicate.Alpha

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id int) predicate.Alpha

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...int) predicate.Alpha

IDNotIn applies the NotIn predicate on the ID field.

func LastUpdate

func LastUpdate(v string) predicate.Alpha

LastUpdate applies equality check predicate on the "LastUpdate" field. It's identical to LastUpdateEQ.

func LastUpdateContains

func LastUpdateContains(v string) predicate.Alpha

LastUpdateContains applies the Contains predicate on the "LastUpdate" field.

func LastUpdateContainsFold

func LastUpdateContainsFold(v string) predicate.Alpha

LastUpdateContainsFold applies the ContainsFold predicate on the "LastUpdate" field.

func LastUpdateEQ

func LastUpdateEQ(v string) predicate.Alpha

LastUpdateEQ applies the EQ predicate on the "LastUpdate" field.

func LastUpdateEqualFold

func LastUpdateEqualFold(v string) predicate.Alpha

LastUpdateEqualFold applies the EqualFold predicate on the "LastUpdate" field.

func LastUpdateGT

func LastUpdateGT(v string) predicate.Alpha

LastUpdateGT applies the GT predicate on the "LastUpdate" field.

func LastUpdateGTE

func LastUpdateGTE(v string) predicate.Alpha

LastUpdateGTE applies the GTE predicate on the "LastUpdate" field.

func LastUpdateHasPrefix

func LastUpdateHasPrefix(v string) predicate.Alpha

LastUpdateHasPrefix applies the HasPrefix predicate on the "LastUpdate" field.

func LastUpdateHasSuffix

func LastUpdateHasSuffix(v string) predicate.Alpha

LastUpdateHasSuffix applies the HasSuffix predicate on the "LastUpdate" field.

func LastUpdateIn

func LastUpdateIn(vs ...string) predicate.Alpha

LastUpdateIn applies the In predicate on the "LastUpdate" field.

func LastUpdateLT

func LastUpdateLT(v string) predicate.Alpha

LastUpdateLT applies the LT predicate on the "LastUpdate" field.

func LastUpdateLTE

func LastUpdateLTE(v string) predicate.Alpha

LastUpdateLTE applies the LTE predicate on the "LastUpdate" field.

func LastUpdateNEQ

func LastUpdateNEQ(v string) predicate.Alpha

LastUpdateNEQ applies the NEQ predicate on the "LastUpdate" field.

func LastUpdateNotIn

func LastUpdateNotIn(vs ...string) predicate.Alpha

LastUpdateNotIn applies the NotIn predicate on the "LastUpdate" field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.Alpha) predicate.Alpha

Or groups predicates with the OR operator between them.

func TestField

func TestField(v string) predicate.Alpha

TestField applies equality check predicate on the "TestField" field. It's identical to TestFieldEQ.

func TestFieldContains

func TestFieldContains(v string) predicate.Alpha

TestFieldContains applies the Contains predicate on the "TestField" field.

func TestFieldContainsFold

func TestFieldContainsFold(v string) predicate.Alpha

TestFieldContainsFold applies the ContainsFold predicate on the "TestField" field.

func TestFieldEQ

func TestFieldEQ(v string) predicate.Alpha

TestFieldEQ applies the EQ predicate on the "TestField" field.

func TestFieldEqualFold

func TestFieldEqualFold(v string) predicate.Alpha

TestFieldEqualFold applies the EqualFold predicate on the "TestField" field.

func TestFieldGT

func TestFieldGT(v string) predicate.Alpha

TestFieldGT applies the GT predicate on the "TestField" field.

func TestFieldGTE

func TestFieldGTE(v string) predicate.Alpha

TestFieldGTE applies the GTE predicate on the "TestField" field.

func TestFieldHasPrefix

func TestFieldHasPrefix(v string) predicate.Alpha

TestFieldHasPrefix applies the HasPrefix predicate on the "TestField" field.

func TestFieldHasSuffix

func TestFieldHasSuffix(v string) predicate.Alpha

TestFieldHasSuffix applies the HasSuffix predicate on the "TestField" field.

func TestFieldIn

func TestFieldIn(vs ...string) predicate.Alpha

TestFieldIn applies the In predicate on the "TestField" field.

func TestFieldIsNil

func TestFieldIsNil() predicate.Alpha

TestFieldIsNil applies the IsNil predicate on the "TestField" field.

func TestFieldLT

func TestFieldLT(v string) predicate.Alpha

TestFieldLT applies the LT predicate on the "TestField" field.

func TestFieldLTE

func TestFieldLTE(v string) predicate.Alpha

TestFieldLTE applies the LTE predicate on the "TestField" field.

func TestFieldNEQ

func TestFieldNEQ(v string) predicate.Alpha

TestFieldNEQ applies the NEQ predicate on the "TestField" field.

func TestFieldNotIn

func TestFieldNotIn(vs ...string) predicate.Alpha

TestFieldNotIn applies the NotIn predicate on the "TestField" field.

func TestFieldNotNil

func TestFieldNotNil() predicate.Alpha

TestFieldNotNil applies the NotNil predicate on the "TestField" field.

func UUID

func UUID(v string) predicate.Alpha

UUID applies equality check predicate on the "Uuid" field. It's identical to UUIDEQ.

func UUIDContains

func UUIDContains(v string) predicate.Alpha

UUIDContains applies the Contains predicate on the "Uuid" field.

func UUIDContainsFold

func UUIDContainsFold(v string) predicate.Alpha

UUIDContainsFold applies the ContainsFold predicate on the "Uuid" field.

func UUIDEQ

func UUIDEQ(v string) predicate.Alpha

UUIDEQ applies the EQ predicate on the "Uuid" field.

func UUIDEqualFold

func UUIDEqualFold(v string) predicate.Alpha

UUIDEqualFold applies the EqualFold predicate on the "Uuid" field.

func UUIDGT

func UUIDGT(v string) predicate.Alpha

UUIDGT applies the GT predicate on the "Uuid" field.

func UUIDGTE

func UUIDGTE(v string) predicate.Alpha

UUIDGTE applies the GTE predicate on the "Uuid" field.

func UUIDHasPrefix

func UUIDHasPrefix(v string) predicate.Alpha

UUIDHasPrefix applies the HasPrefix predicate on the "Uuid" field.

func UUIDHasSuffix

func UUIDHasSuffix(v string) predicate.Alpha

UUIDHasSuffix applies the HasSuffix predicate on the "Uuid" field.

func UUIDIn

func UUIDIn(vs ...string) predicate.Alpha

UUIDIn applies the In predicate on the "Uuid" field.

func UUIDLT

func UUIDLT(v string) predicate.Alpha

UUIDLT applies the LT predicate on the "Uuid" field.

func UUIDLTE

func UUIDLTE(v string) predicate.Alpha

UUIDLTE applies the LTE predicate on the "Uuid" field.

func UUIDNEQ

func UUIDNEQ(v string) predicate.Alpha

UUIDNEQ applies the NEQ predicate on the "Uuid" field.

func UUIDNotIn

func UUIDNotIn(vs ...string) predicate.Alpha

UUIDNotIn applies the NotIn predicate on the "Uuid" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the Alpha queries.

func ByAnimal

func ByAnimal(opts ...sql.OrderTermOption) OrderOption

ByAnimal orders the results by the Animal field.

func ByBigNumber

func ByBigNumber(opts ...sql.OrderTermOption) OrderOption

ByBigNumber orders the results by the BigNumber field.

func ByFirstInsert

func ByFirstInsert(opts ...sql.OrderTermOption) OrderOption

ByFirstInsert orders the results by the FirstInsert field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByLastUpdate

func ByLastUpdate(opts ...sql.OrderTermOption) OrderOption

ByLastUpdate orders the results by the LastUpdate field.

func ByTestField

func ByTestField(opts ...sql.OrderTermOption) OrderOption

ByTestField orders the results by the TestField field.

func ByUUID

func ByUUID(opts ...sql.OrderTermOption) OrderOption

ByUUID orders the results by the Uuid field.

Jump to