Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.Alpha) predicate.Alpha
- func Animal(v string) predicate.Alpha
- func AnimalContains(v string) predicate.Alpha
- func AnimalContainsFold(v string) predicate.Alpha
- func AnimalEQ(v string) predicate.Alpha
- func AnimalEqualFold(v string) predicate.Alpha
- func AnimalGT(v string) predicate.Alpha
- func AnimalGTE(v string) predicate.Alpha
- func AnimalHasPrefix(v string) predicate.Alpha
- func AnimalHasSuffix(v string) predicate.Alpha
- func AnimalIn(vs ...string) predicate.Alpha
- func AnimalLT(v string) predicate.Alpha
- func AnimalLTE(v string) predicate.Alpha
- func AnimalNEQ(v string) predicate.Alpha
- func AnimalNotIn(vs ...string) predicate.Alpha
- func BigNumber(v string) predicate.Alpha
- func BigNumberContains(v string) predicate.Alpha
- func BigNumberContainsFold(v string) predicate.Alpha
- func BigNumberEQ(v string) predicate.Alpha
- func BigNumberEqualFold(v string) predicate.Alpha
- func BigNumberGT(v string) predicate.Alpha
- func BigNumberGTE(v string) predicate.Alpha
- func BigNumberHasPrefix(v string) predicate.Alpha
- func BigNumberHasSuffix(v string) predicate.Alpha
- func BigNumberIn(vs ...string) predicate.Alpha
- func BigNumberLT(v string) predicate.Alpha
- func BigNumberLTE(v string) predicate.Alpha
- func BigNumberNEQ(v string) predicate.Alpha
- func BigNumberNotIn(vs ...string) predicate.Alpha
- func FirstInsert(v string) predicate.Alpha
- func FirstInsertContains(v string) predicate.Alpha
- func FirstInsertContainsFold(v string) predicate.Alpha
- func FirstInsertEQ(v string) predicate.Alpha
- func FirstInsertEqualFold(v string) predicate.Alpha
- func FirstInsertGT(v string) predicate.Alpha
- func FirstInsertGTE(v string) predicate.Alpha
- func FirstInsertHasPrefix(v string) predicate.Alpha
- func FirstInsertHasSuffix(v string) predicate.Alpha
- func FirstInsertIn(vs ...string) predicate.Alpha
- func FirstInsertLT(v string) predicate.Alpha
- func FirstInsertLTE(v string) predicate.Alpha
- func FirstInsertNEQ(v string) predicate.Alpha
- func FirstInsertNotIn(vs ...string) predicate.Alpha
- func ID(id int) predicate.Alpha
- func IDEQ(id int) predicate.Alpha
- func IDGT(id int) predicate.Alpha
- func IDGTE(id int) predicate.Alpha
- func IDIn(ids ...int) predicate.Alpha
- func IDLT(id int) predicate.Alpha
- func IDLTE(id int) predicate.Alpha
- func IDNEQ(id int) predicate.Alpha
- func IDNotIn(ids ...int) predicate.Alpha
- func LastUpdate(v string) predicate.Alpha
- func LastUpdateContains(v string) predicate.Alpha
- func LastUpdateContainsFold(v string) predicate.Alpha
- func LastUpdateEQ(v string) predicate.Alpha
- func LastUpdateEqualFold(v string) predicate.Alpha
- func LastUpdateGT(v string) predicate.Alpha
- func LastUpdateGTE(v string) predicate.Alpha
- func LastUpdateHasPrefix(v string) predicate.Alpha
- func LastUpdateHasSuffix(v string) predicate.Alpha
- func LastUpdateIn(vs ...string) predicate.Alpha
- func LastUpdateLT(v string) predicate.Alpha
- func LastUpdateLTE(v string) predicate.Alpha
- func LastUpdateNEQ(v string) predicate.Alpha
- func LastUpdateNotIn(vs ...string) predicate.Alpha
- func Not(p predicate.Alpha) predicate.Alpha
- func Or(predicates ...predicate.Alpha) predicate.Alpha
- func TestField(v string) predicate.Alpha
- func TestFieldContains(v string) predicate.Alpha
- func TestFieldContainsFold(v string) predicate.Alpha
- func TestFieldEQ(v string) predicate.Alpha
- func TestFieldEqualFold(v string) predicate.Alpha
- func TestFieldGT(v string) predicate.Alpha
- func TestFieldGTE(v string) predicate.Alpha
- func TestFieldHasPrefix(v string) predicate.Alpha
- func TestFieldHasSuffix(v string) predicate.Alpha
- func TestFieldIn(vs ...string) predicate.Alpha
- func TestFieldIsNil() predicate.Alpha
- func TestFieldLT(v string) predicate.Alpha
- func TestFieldLTE(v string) predicate.Alpha
- func TestFieldNEQ(v string) predicate.Alpha
- func TestFieldNotIn(vs ...string) predicate.Alpha
- func TestFieldNotNil() predicate.Alpha
- func UUID(v string) predicate.Alpha
- func UUIDContains(v string) predicate.Alpha
- func UUIDContainsFold(v string) predicate.Alpha
- func UUIDEQ(v string) predicate.Alpha
- func UUIDEqualFold(v string) predicate.Alpha
- func UUIDGT(v string) predicate.Alpha
- func UUIDGTE(v string) predicate.Alpha
- func UUIDHasPrefix(v string) predicate.Alpha
- func UUIDHasSuffix(v string) predicate.Alpha
- func UUIDIn(vs ...string) predicate.Alpha
- func UUIDLT(v string) predicate.Alpha
- func UUIDLTE(v string) predicate.Alpha
- func UUIDNEQ(v string) predicate.Alpha
- func UUIDNotIn(vs ...string) predicate.Alpha
- func ValidColumn(column string) bool
- type OrderOption
- func ByAnimal(opts ...sql.OrderTermOption) OrderOption
- func ByBigNumber(opts ...sql.OrderTermOption) OrderOption
- func ByFirstInsert(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByLastUpdate(opts ...sql.OrderTermOption) OrderOption
- func ByTestField(opts ...sql.OrderTermOption) OrderOption
- func ByUUID(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the alpha type in the database. Label = "alpha" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldUUID holds the string denoting the uuid field in the database. FieldUUID = "Uuid" // FieldFirstInsert holds the string denoting the firstinsert field in the database. FieldFirstInsert = "FirstInsert" // FieldLastUpdate holds the string denoting the lastupdate field in the database. FieldLastUpdate = "LastUpdate" // FieldAnimal holds the string denoting the animal field in the database. FieldAnimal = "Animal" // FieldBigNumber holds the string denoting the bignumber field in the database. FieldBigNumber = "BigNumber" // FieldTestField holds the string denoting the testfield field in the database. FieldTestField = "test_field" // Table holds the table name of the alpha in the database. Table = "alpha" )
Variables ¶
var ( // UUIDValidator is a validator for the "Uuid" field. It is called by the builders before save. UUIDValidator func(string) error // AnimalValidator is a validator for the "Animal" field. It is called by the builders before save. AnimalValidator func(string) error )
var Columns = []string{ FieldID, FieldUUID, FieldFirstInsert, FieldLastUpdate, FieldAnimal, FieldBigNumber, FieldTestField, }
Columns holds all SQL columns for alpha fields.
Functions ¶
func Animal ¶
Animal applies equality check predicate on the "Animal" field. It's identical to AnimalEQ.
func AnimalContains ¶
AnimalContains applies the Contains predicate on the "Animal" field.
func AnimalContainsFold ¶
AnimalContainsFold applies the ContainsFold predicate on the "Animal" field.
func AnimalEqualFold ¶
AnimalEqualFold applies the EqualFold predicate on the "Animal" field.
func AnimalHasPrefix ¶
AnimalHasPrefix applies the HasPrefix predicate on the "Animal" field.
func AnimalHasSuffix ¶
AnimalHasSuffix applies the HasSuffix predicate on the "Animal" field.
func AnimalNotIn ¶
AnimalNotIn applies the NotIn predicate on the "Animal" field.
func BigNumber ¶
BigNumber applies equality check predicate on the "BigNumber" field. It's identical to BigNumberEQ.
func BigNumberContains ¶
BigNumberContains applies the Contains predicate on the "BigNumber" field.
func BigNumberContainsFold ¶
BigNumberContainsFold applies the ContainsFold predicate on the "BigNumber" field.
func BigNumberEQ ¶
BigNumberEQ applies the EQ predicate on the "BigNumber" field.
func BigNumberEqualFold ¶
BigNumberEqualFold applies the EqualFold predicate on the "BigNumber" field.
func BigNumberGT ¶
BigNumberGT applies the GT predicate on the "BigNumber" field.
func BigNumberGTE ¶
BigNumberGTE applies the GTE predicate on the "BigNumber" field.
func BigNumberHasPrefix ¶
BigNumberHasPrefix applies the HasPrefix predicate on the "BigNumber" field.
func BigNumberHasSuffix ¶
BigNumberHasSuffix applies the HasSuffix predicate on the "BigNumber" field.
func BigNumberIn ¶
BigNumberIn applies the In predicate on the "BigNumber" field.
func BigNumberLT ¶
BigNumberLT applies the LT predicate on the "BigNumber" field.
func BigNumberLTE ¶
BigNumberLTE applies the LTE predicate on the "BigNumber" field.
func BigNumberNEQ ¶
BigNumberNEQ applies the NEQ predicate on the "BigNumber" field.
func BigNumberNotIn ¶
BigNumberNotIn applies the NotIn predicate on the "BigNumber" field.
func FirstInsert ¶
FirstInsert applies equality check predicate on the "FirstInsert" field. It's identical to FirstInsertEQ.
func FirstInsertContains ¶
FirstInsertContains applies the Contains predicate on the "FirstInsert" field.
func FirstInsertContainsFold ¶
FirstInsertContainsFold applies the ContainsFold predicate on the "FirstInsert" field.
func FirstInsertEQ ¶
FirstInsertEQ applies the EQ predicate on the "FirstInsert" field.
func FirstInsertEqualFold ¶
FirstInsertEqualFold applies the EqualFold predicate on the "FirstInsert" field.
func FirstInsertGT ¶
FirstInsertGT applies the GT predicate on the "FirstInsert" field.
func FirstInsertGTE ¶
FirstInsertGTE applies the GTE predicate on the "FirstInsert" field.
func FirstInsertHasPrefix ¶
FirstInsertHasPrefix applies the HasPrefix predicate on the "FirstInsert" field.
func FirstInsertHasSuffix ¶
FirstInsertHasSuffix applies the HasSuffix predicate on the "FirstInsert" field.
func FirstInsertIn ¶
FirstInsertIn applies the In predicate on the "FirstInsert" field.
func FirstInsertLT ¶
FirstInsertLT applies the LT predicate on the "FirstInsert" field.
func FirstInsertLTE ¶
FirstInsertLTE applies the LTE predicate on the "FirstInsert" field.
func FirstInsertNEQ ¶
FirstInsertNEQ applies the NEQ predicate on the "FirstInsert" field.
func FirstInsertNotIn ¶
FirstInsertNotIn applies the NotIn predicate on the "FirstInsert" field.
func LastUpdate ¶
LastUpdate applies equality check predicate on the "LastUpdate" field. It's identical to LastUpdateEQ.
func LastUpdateContains ¶
LastUpdateContains applies the Contains predicate on the "LastUpdate" field.
func LastUpdateContainsFold ¶
LastUpdateContainsFold applies the ContainsFold predicate on the "LastUpdate" field.
func LastUpdateEQ ¶
LastUpdateEQ applies the EQ predicate on the "LastUpdate" field.
func LastUpdateEqualFold ¶
LastUpdateEqualFold applies the EqualFold predicate on the "LastUpdate" field.
func LastUpdateGT ¶
LastUpdateGT applies the GT predicate on the "LastUpdate" field.
func LastUpdateGTE ¶
LastUpdateGTE applies the GTE predicate on the "LastUpdate" field.
func LastUpdateHasPrefix ¶
LastUpdateHasPrefix applies the HasPrefix predicate on the "LastUpdate" field.
func LastUpdateHasSuffix ¶
LastUpdateHasSuffix applies the HasSuffix predicate on the "LastUpdate" field.
func LastUpdateIn ¶
LastUpdateIn applies the In predicate on the "LastUpdate" field.
func LastUpdateLT ¶
LastUpdateLT applies the LT predicate on the "LastUpdate" field.
func LastUpdateLTE ¶
LastUpdateLTE applies the LTE predicate on the "LastUpdate" field.
func LastUpdateNEQ ¶
LastUpdateNEQ applies the NEQ predicate on the "LastUpdate" field.
func LastUpdateNotIn ¶
LastUpdateNotIn applies the NotIn predicate on the "LastUpdate" field.
func TestField ¶
TestField applies equality check predicate on the "TestField" field. It's identical to TestFieldEQ.
func TestFieldContains ¶
TestFieldContains applies the Contains predicate on the "TestField" field.
func TestFieldContainsFold ¶
TestFieldContainsFold applies the ContainsFold predicate on the "TestField" field.
func TestFieldEQ ¶
TestFieldEQ applies the EQ predicate on the "TestField" field.
func TestFieldEqualFold ¶
TestFieldEqualFold applies the EqualFold predicate on the "TestField" field.
func TestFieldGT ¶
TestFieldGT applies the GT predicate on the "TestField" field.
func TestFieldGTE ¶
TestFieldGTE applies the GTE predicate on the "TestField" field.
func TestFieldHasPrefix ¶
TestFieldHasPrefix applies the HasPrefix predicate on the "TestField" field.
func TestFieldHasSuffix ¶
TestFieldHasSuffix applies the HasSuffix predicate on the "TestField" field.
func TestFieldIn ¶
TestFieldIn applies the In predicate on the "TestField" field.
func TestFieldIsNil ¶
TestFieldIsNil applies the IsNil predicate on the "TestField" field.
func TestFieldLT ¶
TestFieldLT applies the LT predicate on the "TestField" field.
func TestFieldLTE ¶
TestFieldLTE applies the LTE predicate on the "TestField" field.
func TestFieldNEQ ¶
TestFieldNEQ applies the NEQ predicate on the "TestField" field.
func TestFieldNotIn ¶
TestFieldNotIn applies the NotIn predicate on the "TestField" field.
func TestFieldNotNil ¶
TestFieldNotNil applies the NotNil predicate on the "TestField" field.
func UUIDContains ¶
UUIDContains applies the Contains predicate on the "Uuid" field.
func UUIDContainsFold ¶
UUIDContainsFold applies the ContainsFold predicate on the "Uuid" field.
func UUIDEqualFold ¶
UUIDEqualFold applies the EqualFold predicate on the "Uuid" field.
func UUIDHasPrefix ¶
UUIDHasPrefix applies the HasPrefix predicate on the "Uuid" field.
func UUIDHasSuffix ¶
UUIDHasSuffix applies the HasSuffix predicate on the "Uuid" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the Alpha queries.
func ByAnimal ¶
func ByAnimal(opts ...sql.OrderTermOption) OrderOption
ByAnimal orders the results by the Animal field.
func ByBigNumber ¶
func ByBigNumber(opts ...sql.OrderTermOption) OrderOption
ByBigNumber orders the results by the BigNumber field.
func ByFirstInsert ¶
func ByFirstInsert(opts ...sql.OrderTermOption) OrderOption
ByFirstInsert orders the results by the FirstInsert field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByLastUpdate ¶
func ByLastUpdate(opts ...sql.OrderTermOption) OrderOption
ByLastUpdate orders the results by the LastUpdate field.
func ByTestField ¶
func ByTestField(opts ...sql.OrderTermOption) OrderOption
ByTestField orders the results by the TestField field.
func ByUUID ¶
func ByUUID(opts ...sql.OrderTermOption) OrderOption
ByUUID orders the results by the Uuid field.